summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--SConstruct2
-rw-r--r--build/features.py16
2 files changed, 9 insertions, 9 deletions
diff --git a/SConstruct b/SConstruct
index ea8f63d07e..74f40bd6ad 100644
--- a/SConstruct
+++ b/SConstruct
@@ -38,7 +38,7 @@ available_features = [features.Mad,
features.HSS1394,
features.HID,
features.Bulk,
- features.AppStoreException,
+ features.MacAppStoreException,
features.VinylControl,
features.Shoutcast,
features.Opus,
diff --git a/build/features.py b/build/features.py
index 073a075dfd..a4a38ff30a 100644
--- a/build/features.py
+++ b/build/features.py
@@ -363,9 +363,9 @@ class VinylControl(Feature):
def enabled(self, build):
build.flags['vinylcontrol'] = util.get_flags(build.env,
'vinylcontrol', 0)
# Existence of the appstore option forces vinylcontrol off due to
# licensing issues.
- if build.flags.has_key('appstore') and int(build.flags['appstore']):
+ if build.flags.has_key('macappstore') and int(build.flags['macappstore']):
return False
if int(build.flags['vinylcontrol']):
return True
@@ -1290,22 +1290,22 @@ class AutoDjCrates(Feature):
def sources(self, build):
return ['library/dao/autodjcratesdao.cpp']
-class AppStoreException(Feature):
+class MacAppStoreException(Feature):
def description(self):
return "Build for Mac App Store"
def enabled(self, build):
- build.flags['appstore'] = util.get_flags(build.env,
- 'appstore', 0)
- if int(build.flags['appstore']):
- # Existence of the appstore option forces vinylcontrol off due to
+ build.flags['macappstore'] = util.get_flags(build.env,
+ 'macappstore', 0)
+ if int(build.flags['macappstore']):
+ # Existence of the macappstore option forces vinylcontrol off due to
# licensing issues.
build.flags['vinylcontrol'] = 0
return True
return False
def add_options(self, build, vars):
- vars.Add('appstore', 'Set to 1 to indicate the build is for the Mac App Store', 1)
+ vars.Add('macappstore', 'Set to 1 to indicate the build is for the Mac App Store', 1)
def configure(self, build, conf):
if not self.enabled(build):
@@ -363,9 +363,9 @@ class VinylControl(Feature):
build.flags['vinylcontrol'] = util.get_flags(build.env,
'vinylcontrol', 0)
- # Existence of the appstore option forces vinylcontrol off due to
+ # Existence of the macappstore option forces vinylcontrol off due to
# licensing issues.